/*
 *   Copyright (C) 2008 Peter Grasch <peter.grasch@bedahr.org>
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License version 2,
 *   or (at your option) any later version, as published by the Free
 *   Software Foundation
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details
 *
 *   You should have received a copy of the GNU General Public
 *   License along with this program; if not, write to the
 *   Free Software Foundation, Inc.,
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#include "screengrid.h"
#include <QKeyEvent>

ScreenGrid::ScreenGrid(QWidget* parent) : QWidget(parent, Qt::WindowStaysOnTopHint|Qt::FramelessWindowHint)
{
  setWindowTitle("Screengrid"); // invisible anyway; no need for translation
}

void ScreenGrid::keyPressEvent(QKeyEvent *event)
{
  if (!event) return;
  if (event->key()== Qt::Key_Escape) emit cancel();
}
